#!/bin/sh
#
# WARLORD (UN)INSTALL Script (warlord.sh)
# --------------------------------------
#
# Purpose:      To install and uninstall the WARLORD patch
#
# Parameters:   -u (uninstall)
#	        VRF (Version to be uninstalled)
#
# Usage:        ./warlord.sh [-u] [Version]
#
#		Installation: 	./warlord.sh
# 		Uninstallation: ./warlord.sh -u 105
#
# Return Codes: 0 - Patches applied successfully
#		1 - Original QMAIL files not found (Patch not extracted in QMAIL source directory)
#		2 - Patch files not found 
#
# Output:	warlord.log
#
# History:      1.0.1 - Erwin Hoffmann - Gentoo fixes
#		1.0.2 -			removed '-v' from cp
#
#---------------------------------------------------------------------------------------
#
DATUM=$(date)
LOCDIR=${PWD}
QMAILHOME=$(head -n 1 conf-qmail)
SOLARIS=$(sh ./find-systype.sh | grep -ci "SunOS")
LOGFILE=warlord.log
TARGETS=FILES.warlord
CONF=conf-warlord
IFSKEEP=${IFS}
REL=137 # Should be identical to WARLORD level


if [ $# -eq 0 ] ; then
	echo "Running warlord.sh INSTALLATION at $DATUM for Release $REL <<<" | tee -a $LOGFILE 2>&1 
	for FILE in $(grep "^= " ${TARGETS} | awk '{print $2}'); do
		echo "Targeting file $FILE ..." | tee -a $LOGFILE 2>&1
		if [ -s ${FILE} ] ; then
			cp ${FILE} ${FILE}.$REL | tee -a $LOGFILE 2>&1
			echo "--> ${FILE} copied to ${FILE}.$REL" | tee -a $LOGFILE 2>&1
		else
			echo "${FILE} not found !"
			exit 1
		fi
		if [ -s ${FILE}.patch ] ; then
			if [ ${SOLARIS} -gt 0 ]; then
				echo "--> Patching qmail source file ${FILE} for Solaris ...." | tee -a $LOGFILE 2>&1
				patch -i ${FILE}.patch ${FILE} 2>&1 | tee -a $LOGFILE
			else
				echo "--> Patching qmail source file ${FILE}  ...." | tee -a $LOGFILE 2>&1
				patch ${FILE} ${FILE}.patch 2>&1 | tee -a $LOGFILE
			fi
		else
			echo "!! ${FILE}.patch not found !"
			exit 2
		fi
	done 

	echo "Copying documentation and samples to ${QMAILHOME}/doc/ ..." | tee -a $LOGFILE 2>&1 

	cp [A-Z]*.warlord ${QMAILHOME}/doc/ | tee -a $LOGFILE 2>&1
	cp  bad*   ${QMAILHOME}/doc/ | tee -a $LOGFILE 2>&1

# Now go for the uninstallation....

elif [ "$1" = "-u" ] ; then

# Get the Version Number from INPUT 

	REL=$2
	echo "Running warlord.sh UNINSTALLATION at $DATUM for Release $REL <<<" | tee -a $LOGFILE 2>&1 
	for FILE in $(grep "^= " ${TARGETS} | awk '{print $2}'); do
		echo "Targeting file $FILE ..." | tee -a $LOGFILE 2>&1
		if [ -s ${FILE}.$REL ] ; then
			mv ${FILE}.$REL ${FILE} | tee -a $LOGFILE 2>&1
			echo "--> ${FILE}.$REL moved to ${FILE}" | tee -a $LOGFILE 2>&1
		else
			echo "!! ${FILE}.$REL not found !"
		fi
	done
fi

exit 0
